/* SIMulador Sistema PLAnetario, M.Alvarez 2018
 * Trabajo para el TFM
 * del Master de Astrofísica de la UAM
 * 
 * Copyright (c) 2018 Mariano Alvarez Fernandez (malfer@telefonica.net)
 *
 * This file is part of simspla
 *
 * simspla is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * simspla is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with rebound.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef _MREVOL_H_
#define _MREVOL_H_

#define GOOD_RETURN 0
#define BAD_RETURN 1

typedef struct { // registro (rango) de evolucion masa y radio
    double rlos;   // radio perdido por año o ganado si negativo (unidades arbitrarias)
    double r;      // radio al final del rango (unidades arbitrarias)
    double mlos;   // masa perdida por año (unidades arbitrarias)
    double m;      // masa al final del rango (unidades arbitrarias)
    double dt;     // duración del rango en años
    double t;      // tiempo en años al final del rango
} MRERange;

typedef struct {     // evolución de masa y radio
    long nranges;      // número de rangos
    MRERange *range;   // rangos, se cargan desde fichero
    double init_t;     // t en el inicio de la simulación en años
    double init_tsim;  // t en el inicio de la simulación en unidades de la simulación
    double init_msim;  // masa en t inicio de simulación (unidades simulación)
    double init_rsim;  // radio en t incio de la simulación (unidades simulación)
    double utsim;      // correspondencia en años de la unidad de tiempo de la simulación
    long init_range;   // rango donde inicia la simulación
    long act_range;    // rango actual    
} MREvolution;

MREvolution *mre_new(long nranges);
MREvolution *mre_load(char *fname);
int mre_setinit(MREvolution *mre, double t, double tsim, double utsim, double msim, double rsim);
void mre_getmrsim(MREvolution *mre, double tsim, double *msim, double *rsim);

#endif /* _MREVOL_H_ */
